# AIML & DBMS Lab program
              
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   
## Functions 
- isprime(number)
- tsp(graph,starting point)
- nqueen(number)
- longtictactoe()

## Programs will be returned for call
### a lab

- p_multiplicationtable
- p_primeornot
- p_factorial
- p_list_operations
- p_list_methods
- p_chatbot
- p_set_operation
- p_count_s1_in_s2
- p_dictionary_operations
- p_n_queen
- p_tsp
- p_longtictactoe

### - <u>dbms lab</u>
- p_library
- p_order
- p_movie
- p_college
- p_comp  

## Usage
```
import tempailab
```

## Get the list of sql programs

```
print(tempailab.sql_programs)
```

## Get the list of ai programs

```
print(tempailab.ai_programs)
```

## Example
### run it 
```
import tempailab
print(tempailab.isprime(3))
```
### Output
```
3 is a prime number
```
